@@ -38,7 +38,7 @@ call_block = function(block) {
     )
     if (!params$eval) return('')
     cmds = lapply(sc_split(params$child), knit_child, options = block$params)
-    out = paste(unlist(cmds), collapse = '\n')
+    out = one_string(unlist(cmds))
     return(out)
   }
 
@@ -161,7 +161,7 @@ block_exec = function(options) {
   # only evaluate certain lines
   if (is.numeric(ev <- options$eval)) {
     # group source code into syntactically complete expressions
-    if (isFALSE(options$tidy)) code = sapply(highr:::group_src(code), paste, collapse = '\n')
+    if (isFALSE(options$tidy)) code = sapply(highr:::group_src(code), one_string)
     iss = seq_along(code)
     code = comment_out(code, '##', setdiff(iss, iss[ev]), newline = FALSE)
   }
@@ -267,7 +267,7 @@ block_exec = function(options) {
     if (options$autodep) {
       # you shall manually specify global object names if find_symbols() is not reliable
       cache$objects(
-        objs, options$cache.globals %n% find_symbols(code), options$label,
+        objs, options$cache.globals %n% find_globals(code), options$label,
         options$cache.path
       )
       dep_auto()
@@ -304,8 +304,8 @@ chunk_device = function(
   dev_new = function() {
     # actually I should adjust the recording device according to dev, but here I
     # have only considered the png and tikz devices (because the measurement
-    # results can be very different especially with the latter, see #1066), and
-    # also the cairo_pdf device (#1235)
+    # results can be very different especially with the latter, see #1066), the
+    # cairo_pdf device (#1235), and svg (#1705)
     if (identical(dev, 'png')) {
       do.call(grDevices::png, c(list(
         filename = tmp, width = width, height = height, units = 'in', res = dpi
@@ -321,6 +321,10 @@ chunk_device = function(
       do.call(grDevices::cairo_pdf, c(list(
         filename = tmp, width = width, height = height
       ), get_dargs(dev.args, 'cairo_pdf')))
+    } else if (identical(dev, 'svg')) {
+      do.call(grDevices::svg, c(list(
+        filename = tmp, width = width, height = height
+      ), get_dargs(dev.args, 'svg')))
     } else if (identical(getOption('device'), pdf_null)) {
       if (!is.null(dev.args)) {
         dev.args = get_dargs(dev.args, 'pdf')
@@ -464,10 +468,10 @@ process_tangle.block = function(x) {
   }
   if (isFALSE(params$purl)) return('')
   label = params$label; ev = params$eval
-  if (params$engine != 'R') return(comment_out(knit_code$get(label)))
+  if (params$engine != 'R') return(one_string(comment_out(knit_code$get(label))))
   code = if (!isFALSE(ev) && !is.null(params$child)) {
     cmds = lapply(sc_split(params$child), knit_child)
-    paste(unlist(cmds), collapse = '\n')
+    one_string(unlist(cmds))
   } else knit_code$get(label)
   # read external code if exists
   if (!isFALSE(ev) && length(code) && any(grepl('read_chunk\\(.+\\)', code))) {
@@ -475,14 +479,14 @@ process_tangle.block = function(x) {
   }
   code = parse_chunk(code)
   if (isFALSE(ev)) code = comment_out(code, params$comment, newline = FALSE)
-  if (opts_knit$get('documentation') == 0L) return(paste(code, collapse = '\n'))
+  if (opts_knit$get('documentation') == 0L) return(one_string(code))
   label_code(code, x$params.src)
 }
 #' @export
 process_tangle.inline = function(x) {
 
   output = if (opts_knit$get('documentation') == 2L) {
-    output = paste(line_prompt(x$input.src, "#' ", "#' "), collapse = '\n')
+    output = one_string(line_prompt(x$input.src, "#' ", "#' "))
   } else ''
 
   code = x$code
@@ -496,13 +500,13 @@ process_tangle.inline = function(x) {
     output = c(output, cout, '')
   }
 
-  paste(output, collapse = '\n')
+  one_string(output)
 }
 
 
 # add a label [and extra chunk options] to a code chunk
 label_code = function(code, label) {
-  code = paste(c('', code, ''), collapse = '\n')
+  code = one_string(c('', code, ''))
   paste0('## ----', stringr::str_pad(label, max(getOption('width') - 11L, 0L), 'right', '-'),
          '----', code)
 }
